global datapath "/Users/tsimcoe/Dropbox (BOSTON UNIVERSITY)/BRDIS/EBay/data"
global figpath "/Users/tsimcoe/Dropbox (BOSTON UNIVERSITY)/BRDIS/EBay/figures"
set scheme s2mono

**************
** Figure 1 **
**************
import excel "$datapath/patent_data/wipo-counts.xlsx", sheet("Sheet1") firstrow clear
replace US = US/1000
replace EP = EP/1000
quietly sum US
gen top = `r(max)'

twoway (area top Year if Year>=2007 & Year <=2009, bcolor(gs12)) (line US EP Year, lpat(solid dash)),  xline(2006) legend(label(2 "USPTO") lab(3 "EPO") order(2 3)) ytitle("Total Patent Applications (1000's)" " ") xtitle("")
graph export "$figpath/us-v-epo-apps.pdf", replace


**************
** Figure 2 **
**************
use "$datapath/patent_data/pat_naics.dta", clear
gen top = 100
twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line n_pat1 n_pat2 n_pat3 year if (year>=1990 & year <=2012), lpat(solid dash shortdash)), xline(2006)  legend(label(2 "Computing") lab(3 "Life Sciences") lab(4 "Other") rows(1) order(2 3 4)) ytitle("U.S. Patents Issued (1000's)" " ") xtitle("")
graph export "$figpath/us-pats-industry.pdf", replace


**************
** Figure 3 **
**************
use "$datapath/R&D_Productivity/rdseries.dta", replace
gen top = 350

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line TotalBusRD ttlRD year if (year>=1990 & year <=2013), lpat(solid dash)), xline(2006)  ytitle("Business R&D ($ billions)" " ") xtitle("") legend(lab(2 "NSF") lab(3 "Compustat") order(2 3)) 
graph export "$figpath/us-compustat-rd.pdf", replace


**************
** Figure 4 **
**************
keep if year>=1999
quietly sum othRD
replace top = `r(max)'

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line hlthRD techRD othRD year, lpat(solid dash shortdash) xsc(r(1998(5)2013))), legend(label(2 "Life Sciences") lab(3 "Computing") lab(4 "Other") order(2 3 4) rows(1)) xline(2006) ytitle("Total R&D ($ billion)" " ") xtitle("")
graph export "$figpath/us-compustat-ind.pdf", replace


**************
** Figure 5 **
**************
use "$datapath/venture/pwcvctotals.dta", clear
quietly sum ttlAmount
gen top = 80

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line ttlAmount seedAmt year, lpat(solid dash) xlabel(2002(5)2017)), legend(label(2 "Total Funding") lab(3 "Early & Seed Rounds") order(2 3)) ytitle("Venture Capital Investment ($ billion)" " ") xtitle("") xline(2006)
graph export "$figpath/vc-total.pdf", replace


**************
** Figure 6 **
**************
replace top = 60

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line ttlTech ttlLife seedTech seedLife year, lpat(solid shortdash dot longdash) xlabel(2002(5)2017)), legend(label(2 "Total Computing") lab(3 "Total Life Science") label(4 "Seed Computing") label(5 "Seed Life Science") order(2 3 4 5)) ytitle("Total VC Funding ($ billion)" " ") xtitle("") xline(2006)
graph export "$figpath/vc-industry.pdf", replace


**************
** Figure 7 **
**************
use "$datapath/R&D_Productivity/mfgtfp.dta", clear
twoway (line tfp4 year if industry == 1) (line tfp4 year if industry == 2) (line tfp4 year if industry == 0) , legend(lab(3 "Other Mfg") lab(1 "Computers") lab(2 "Pharma") col(3))  ytitle("Total Factor Productivity (2006=1)" " ") xtitle("")
graph export "$figpath/tfproductivity.pdf", replace

****************
** Figure A.1 **
****************
use "$datapath/patent_data/patent_combined_wide.dta", clear
rename applicationYear year
gen top = 80
gen usTotal = lifeScienceNumPatUSPTO + computingNumPatUSPTO + otherNumPatUSPTO
gen epoTotal = lifeScienceNumPatEPO + computingNumPatEPO + otherNumPatEPO 

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line lifeScienceNumPatUSPTO lifeScienceNumPatEPO year if year>=1990 & year <=2011, lpattern(solid dash)), ylabel(0(20)80) xline(2006) ytitle("Patents Issued (1000's)" " ") xtitle("") title("Life Sciences") legend(off)
graph save "$figpath/usEpoLife.gph", replace

twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line computingNumPatUSPTO computingNumPatEPO year if year>=1990 & year <=2011, lpattern(solid dash)), ylabel(0(20)80) xline(2006) ytitle("") xtitle("") title("Computing") legend(off)
graph save "$figpath/usEpoComp.gph", replace

replace top = 120
twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line otherNumPatUSPTO otherNumPatEPO year if year>=1990 & year <=2011, lpattern(solid dash)), ylabel(0(30)120) xline(2006) ytitle("Patents Issued (1000's)" " ") xtitle("") title("Other") legend(lab(2 "USPTO") lab(3 "EPO") order(2 3))
graph save "$figpath/usEpoOth.gph", replace

replace top = 240
twoway (area top year if year>=2007 & year <=2009, bcolor(gs12)) (line usTotal epoTotal year if year>=1990 & year <=2011, lpattern(solid dash)), ylabel(0(60)240) xline(2006) ytitle("") xtitle("") title("Total") legend(lab(2 "USPTO") lab(3 "EPO") order(2 3))
graph save "$figpath/usEpoTotal.gph", replace

graph combine "$figpath/usEpoLife.gph" "$figpath/usEpoComp.gph" "$figpath/usEpoOth.gph" "$figpath/usEpoTotal.gph"
graph export "$figpath/combined_techgroup_grid.png", replace
graph export "$figpath/combined_techgroup_grid.pdf", replace
